==> react-10.0.0.tgz: package/es/Label/index.js <==
import "core-js/modules/es6.object.assign";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
/**
 * @category controls
 * @component label
 * @variations collab-ui-react
 */

var Label = function Label(_ref) {
  var className = _ref.className,
      htmlFor = _ref.htmlFor,
      label = _ref.label,
      theme = _ref.theme,
      props = _objectWithoutPropertiesLoose(_ref, ["className", "htmlFor", "label", "theme"]);

  return React.createElement("label", _extends({
    className: "" + (className ? " " + className : '') + ("" + (theme ? " cui-label--" + theme : '')),
    htmlFor: htmlFor
  }, props), React.createElement("span", null, label));
};

Label.propTypes = {
  /** @prop HTML class name for associated Input | '' */
  className: PropTypes.string,

  /** @prop HTML ID for associated Input | null */
  htmlFor: PropTypes.string.isRequired,

  /** @prop Required Label text | null */
  label: PropTypes.string.isRequired,

  /** @prop Set Label's color theme | '' */
  theme: PropTypes.string
};
Label.defaultProps = {
  className: '',
  htmlFor: null,
  label: null,
  theme: ''
};
Label.displayName = 'Label';
export default Label;
/**
* @name Default Label
* @description Labels are useful.
*
* @category controls
* @component label
* @section default
*
* @js
import { Label } from '@collab-ui/react';

export default function Default() {
  return (
    <div className='row'>
      <Label
        htmlFor='label1'
        label='Default Label'
      />
    </div>
  );
}

**/

==> react-10.0.8.tgz: package/es/Label/index.js <==
import "core-js/modules/es6.object.assign";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
/**
 * @category controls
 * @component label
 * @variations collab-ui-react
 */

var Label = function Label(_ref) {
  var className = _ref.className,
      htmlFor = _ref.htmlFor,
      label = _ref.label,
      theme = _ref.theme,
      props = _objectWithoutPropertiesLoose(_ref, ["className", "htmlFor", "label", "theme"]);

  return React.createElement("label", _extends({
    className: "" + (className ? " " + className : '') + ("" + (theme ? " cui-label--" + theme : '')),
    htmlFor: htmlFor
  }, props), React.createElement("span", null, label));
};

Label.propTypes = {
  /** @prop HTML class name for associated Input | '' */
  className: PropTypes.string,

  /** @prop HTML ID for associated Input | null */
  htmlFor: PropTypes.string.isRequired,

  /** @prop Required Label text | null */
  label: PropTypes.string.isRequired,

  /** @prop Set Label's color theme | '' */
  theme: PropTypes.string
};
Label.defaultProps = {
  className: '',
  htmlFor: null,
  label: null,
  theme: ''
};
Label.displayName = 'Label';
export default Label;
/**
* @name Default Label
* @description Labels are useful.
*
* @category controls
* @component label
* @section default
*
* @js
import { Label } from '@collab-ui/react';

export default function LabelDefault() {
  return (
    <Label
      htmlFor='label1'
      label='Default Label'
    />
  );
}

**/
